Class: Rig::Command::Account::Main

Inherits:
Rig::Command::Abstract show all
Defined in:
lib/rig/command/account.rb

Overview

TODO: figure out how to make this work with YAML references class Change < Abstract PROPS = %wawskey dnszone region parameter "PROPERTY", "the property of config to change, must be one of #PROPS.inspect" parameter "VALUE", "the value to set for the property" def execute case property when "awsid" Rig.account[:aws_access_key_id] = value Rig.save_account when "awskey" Rig.account[:aws_secret_access_key] = value Rig.save_account when "dnszone" Rig.account = value Rig.save_account when "region" Rig.account = value Rig.save_account else puts "Property #property not supported" end end end

Method Summary

Methods inherited from Rig::Command::Abstract

#execute, #instance_list, #print_table